vfbLib.parsers.base.GlyphEncodingParser
=======================================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: GlyphEncodingParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphEncodingParser.__init__
      ~GlyphEncodingParser.parse
      ~GlyphEncodingParser.parse_hex
      ~GlyphEncodingParser.read_double
      ~GlyphEncodingParser.read_doubles
      ~GlyphEncodingParser.read_float
      ~GlyphEncodingParser.read_floats
      ~GlyphEncodingParser.read_int16
      ~GlyphEncodingParser.read_int32
      ~GlyphEncodingParser.read_int8
      ~GlyphEncodingParser.read_str
      ~GlyphEncodingParser.read_str_all
      ~GlyphEncodingParser.read_uint16
      ~GlyphEncodingParser.read_uint32
      ~GlyphEncodingParser.read_uint8
      ~GlyphEncodingParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphEncodingParser.encoding
      ~GlyphEncodingParser.master_count
      ~GlyphEncodingParser.stream
      ~GlyphEncodingParser.ttStemsH_count
      ~GlyphEncodingParser.ttStemsV_count
   
   